@@ -21,6 +21,8 @@ sub is_follow_event           { 0 }
 sub is_unfollow_event         { 0 }
 sub is_join_event             { 0 }
 sub is_leave_event            { 0 }
+sub is_member_join_event      { 0 }
+sub is_member_leave_event     { 0 }
 sub is_postback_event         { 0 }
 sub is_beacon_detection_event { 0 }
 
